@@ -5,31 +5,36 @@
 
 using ::arma::accu;
 using ::arma::as_scalar;
-using ::arma::colvec;
-using ::arma::cube;
+using ::arma::clamp;
 using ::arma::eye;
 using ::arma::index_min;
 using ::arma::join_cols;
 using ::arma::linspace;
-using ::arma::mat;
+using ::arma::log_det_sympd;
 using ::arma::max;
 using ::arma::min;
 using ::arma::norm;
-using ::arma::rowvec;
+using ::arma::ones;
 using ::arma::sign;
 using ::arma::solve;
-using ::arma::ucolvec;
-using ::arma::vec;
 using ::arma::zeros;
 using ::Rcpp::as;
+using ::Rcpp::Named;
+using ::Rcpp::stop;
+
+using ::arma::colvec;
+using ::arma::cube;
+using ::arma::mat;
+using ::arma::rowvec;
+using ::arma::ucolvec;
+using ::arma::uvec;
+using ::arma::vec;
 using ::Rcpp::Environment;
 using ::Rcpp::Function;
 using ::Rcpp::InternalFunction;
 using ::Rcpp::List;
-using ::Rcpp::Named;
 using ::Rcpp::Nullable;
 using ::Rcpp::NumericVector;
-using ::Rcpp::stop;
 using ::Rcpp::S4;
 using ::std::function;
 using ::std::string;
