@@ -9,8 +9,8 @@ testthat::test_that(
     testthat::expect_equal(
       result@cp_set,
       c(
-        177, 264, 394, 534, 579, 656, 788, 811, 869, 934,
-        966, 1051, 1141, 1286, 1319, 1368, 1568, 1657,
+        177, 264, 401, 534, 579, 656, 788, 811, 869,
+        934, 966, 1051, 1141, 1286, 1319, 1386, 1657,
         1724, 1906, 1972, 1996, 2041, 2146, 2200
       )
     )
